=====================================
Bare Metal Service Installation Guide
=====================================

The Bare Metal service is a collection of components that provides support to
manage and provision physical machines.

This chapter assumes a working setup of OpenStack following the
`OpenStack Installation Guides <https://docs.openstack.org/#install-guides>`_.
It contains the following sections:

.. toctree::
   :maxdepth: 2

   get_started.rst
   refarch/index
   install.rst
   configure-integration.rst
   deploy-ramdisk.rst
   setup-drivers.rst
   enrollment.rst
   standalone.rst
   configdrive.rst
   advanced.rst
   troubleshooting.rst
   next-steps.rst
